from typing import List

from numpy import (
    RankWarning as RankWarning,
    poly1d as poly1d,
)

__all__: List[str]

def poly(seq_of_zeros): ...
def roots(p): ...
def polyint(p, m=..., k=...): ...
def polyder(p, m=...): ...
def polyfit(x, y, deg, rcond=..., full=..., w=..., cov=...): ...
def polyval(p, x): ...
def polyadd(a1, a2): ...
def polysub(a1, a2): ...
def polymul(a1, a2): ...
def polydiv(u, v): ...
